========
Examples
========

A set of example is provided in the `examples` folder to getting started with biosiglive API. Each example can be run without any data connection using the custom interface implemented in the example `custom_interface.py`. 
Be aware that if you want to run the example with a real interface, you will need to install the corresponding SDK and to connect to the device. To see the documentation of a specific option please look at the API documentation. 

.. toctree::
   :maxdepth: 2
   
   custom_interface
   EMG_streaming
   cadence
   get_server
   inverse
   live_mvc
   markers
   save
   stream
   live_plot
   server
   


